#GENERATION OF RESULTS OF MAYFIELD LOGISTIC REGRESSIONS IN SECTION 3.4.: "NEST SUCCESS"


#Load required R package
library(RMark)


#Load data 
Data <- read.table(file = "dataset_nest_success_Mayfield.csv", header = TRUE, sep = ";", dec = ".")


#Delete NAs
Data <- subset(Data, subset = Data$Freq != "NA")


#Create binary variables

  #Nesting habitat
for(i in unique(Data$Nesting_habitat)){
  print(i)
  if(nchar(i)>10){
    i1<-i
    i<-substr(i1,1,9)
    Data[[i]]<-ifelse(Data$Nesting_habitat==i1,1,0)
  }
  else{
    Data[[i]]<-ifelse(Data$Nesting_habitat==i,1,0)
  }
}

  #Year
Data$Year18 <- 0
Data$Year18[Data$Year == "2018"] <- 1
Data$Year19 <- 0
Data$Year19[Data$Year == "2019"] <- 1

  #Radio_tagged
Data$Tagyes <- 0
Data$Tagyes[Data$Radio_tagged == "yes"] <- 1
Data$Tagno <- 0
Data$Tagno[Data$Radio_tagged == "no"] <- 1


#Create habitat ("S.habitat") and seasonal model ("S.season")
Pr_data <- process.data(Data, nocc=110, model="Nest")
S.habitat= list(formula= ~ Sugar_beet + Corn + Summer_cr + Mowed_are + Set_aside + Linear_st + Year19 + Tagyes)
S.season = list(formula = ~ First_egg + Year19 + Tagyes)


#Create model list
Model_list = create.model.list("Nest")
Datea.ddl<-make.design.data(Pr_data)


#Run Mayfield logistic regressions
daten_results = mark.wrapper(Model_list,
                               data = Pr_data,
                               adjust = FALSE)


#Show results
daten_results$S.habitat
daten_results$S.season


#Create formula to calculate p-values
p_value_func<-function(est,u,l){
  SE=(u-l)/(2*qnorm(0.975))
  z<-est/SE
  p=2*pnorm(-abs(z))
  return(p)
}


#Calculate p-values of habitat model

  #Intercept 
p_value_func(4.672,5.979,3.366)

  #Sugar_beet
p_value_func(0.056,2.254,-2.142)

  #Corn
p_value_func(-2.937,-1.010,-4.865)

  #Summer_crop
p_value_func(-0.846,1.429,-3.121)

  #Mowed_areas
p_value_func(-1.643,0.118,-3.404)

  #Set_aside
p_value_func(-0.593,0.867,-2.053)

  #Linear_structures
p_value_func(-2.009,-0.663,-3.356)

  #Year
p_value_func(-0.289,0.816,-1.393)

  #Radio_tagged
p_value_func(-1.205,-0.116,-2.294)


#Calculate p-values of seasonal model

  #Intercept
p_value_func(4.362,5.630,3.095)

  #First_egg
p_value_func(-0.006,0.017,-0.028)

  #Year
p_value_func(-0.522,0.473,-1.517)

  #Radio_tagged
p_value_func(-0.979,-0.077,-1.882)


#Create formula to calculate standard error and 95%-confidence intervals of the DNS per model
std_err_func<-function(day=22,dsr,se_dsr){
  p<-dsr^(day-1)
  se_est<-sqrt(((day-1)*dsr^(day-2))^2*se_dsr^2)
  C=exp(2*se_est/(p*(1-p)))
  p_L<-p/(p+(1-p)*C)
  p_U<-p/(p+(1-p)/C)
  confint_est<-c(p_L,p_U)
  est<-dsr^(day-1)
  return(list("est"=est,"confint"=confint_est,"se"=se_est))
}


#Calculate standard error and 95%-confidence intervals of the DNS according to the habitat model
std_err_func(day=23, dsr= 0.9734277, se_dsr=0.0079905)


##Calculate standard error and 95%-confidence intervals of the DNS according to the seasonal model
std_err_func(day=23, dsr= 0.9706570, se_dsr=0.0075488)


